@@ -31,7 +31,9 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, abs
                            outfile=None, wait=True):
     """
     Plots the classifers for the given list of predictions.
+
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
+
     :param predictions: the predictions to plot
     :type predictions: list
     :param absolute: whether to use absolute errors as size or relative ones
@@ -99,6 +101,7 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, abs
 def generate_thresholdcurve_data(evaluation, class_index):
     """
     Generates the threshold curve data from the evaluation object's predictions.
+
     :param evaluation: the evaluation to obtain the predictions from
     :type evaluation: Evaluation
     :param class_index: the 0-based index of the class-label to create the plot for
@@ -117,6 +120,7 @@ def get_thresholdcurve_data(data, xname, yname):
     """
     Retrieves x and y columns from  of the data generated by the weka.classifiers.evaluation.ThresholdCurve
     class.
+
     :param data: the threshold curve data
     :type data: Instances
     :param xname: the name of the X column
@@ -140,6 +144,7 @@ def get_thresholdcurve_data(data, xname, yname):
 def get_auc(data):
     """
     Calculates the area under the ROC curve (AUC).
+
     :param data: the threshold curve data
     :type data: Instances
     :return: the area
@@ -152,6 +157,7 @@ def get_auc(data):
 def get_prc(data):
     """
     Calculates the area under the precision recall curve (PRC).
+
     :param data: the threshold curve data
     :type data: Instances
     :return: the area
@@ -164,7 +170,9 @@ def get_prc(data):
 def plot_roc(evaluation, class_index=None, title=None, key_loc="lower right", outfile=None, wait=True):
     """
     Plots the ROC (receiver operator characteristics) curve for the given predictions.
+
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
+
     :param evaluation: the evaluation to obtain the predictions from
     :type evaluation: Evaluation
     :param class_index: the list of 0-based indices of the class-labels to create the plot for
@@ -214,7 +222,9 @@ def plot_roc(evaluation, class_index=None, title=None, key_loc="lower right", ou
 def plot_prc(evaluation, class_index=None, title=None, key_loc="lower center", outfile=None, wait=True):
     """
     Plots the PRC (precision recall) curve for the given predictions.
+
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
+
     :param evaluation: the evaluation to obtain the predictions from
     :type evaluation: Evaluation
     :param class_index: the list of 0-based indices of the class-labels to create the plot for
@@ -265,7 +275,8 @@ def plot_learning_curve(classifiers, train, test=None, increments=100, metric="p
                         title="Learning curve", label_template="[#] @ $", key_loc="lower right",
                         outfile=None, wait=True):
     """
-    Plots
+    Plots a learning curve.
+
     :param classifiers: list of Classifier template objects
     :type classifiers: list of Classifier
     :param train: dataset to use for the building the classifier, used for evaluating it test set None
